@@ -23,14 +23,13 @@
 #ifndef ROXDOKUVIEW_h
 #define ROXDOKUVIEW_h
 
-#include <qgl.h>
-#include <qpixmap.h>
-#include <qpainter.h>
-#include <qimage.h>
-//Added by qt3to4:
-#include <QWheelEvent>
+#include <QGL>
+#include <QImage>
 #include <QMouseEvent>
+#include <QPainter>
+#include <QPixmap>
 #include <QTimer>
+#include <QWheelEvent>
 
 #include "ArcBall.h"
 
@@ -57,14 +56,14 @@ public:
 
 	virtual QString status() const;
 
-	void initializeGL();
+	void initializeGL() override;
 
-	void resizeGL(int w, int h );
+	void resizeGL(int w, int h ) override;
 
-	QWidget* widget() { return this; }
+	QWidget* widget() override { return this; }
 
 public slots:
-	void selectValue(int value);
+	void selectValue(int value) override;
 	void settingsChanged();
 	void enterValue(int value);
 
@@ -72,22 +71,22 @@ signals:
 	void valueSelected(int value); // Never used but connected to
 
 protected:
-	void paintGL();
+	void paintGL() override;
 
 	void myDrawCube(bool highlight, int cell,
 			GLfloat x, GLfloat y, GLfloat z,
 			bool outside);
 
 	void Selection(int mouse_x, int mouse_y);
-	void mouseReleaseEvent ( QMouseEvent * e ){
+	void mouseReleaseEvent ( QMouseEvent * e )override {
 		if(e->button() == Qt::LeftButton) m_isClicked = false;
 	}
-	void mousePressEvent ( QMouseEvent * e ){
+	void mousePressEvent ( QMouseEvent * e )override {
 		if(e->button() == Qt::LeftButton) m_isClicked = true;
 	}	
-	void mouseMoveEvent(QMouseEvent* e) ;
-	void mouseDoubleClickEvent(QMouseEvent* e);
-	void wheelEvent (QWheelEvent* e){
+	void mouseMoveEvent(QMouseEvent* e)  override;
+	void mouseDoubleClickEvent(QMouseEvent* e) override;
+	void wheelEvent (QWheelEvent* e)override {
 		m_wheelmove += e->delta() * .02;
 		updateGL();
 	}
